#
# spec file for package transmission
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_version    5.6
%define glibmm_version 2.60.0
# Ninja has greater speed than GNU Make. And it provides better error output.
%bcond_without ninja
%bcond_with    webui
%if %{with ninja}
%define __builder ninja
#BuildIgnore:     make
%endif
%if %{with webui}
%define webui_opt ON
%else
%define webui_opt OFF
%endif
Name:           transmission
Version:        4.0.6
Release:        1.1
Summary:        A BitTorrent client with multiple UIs
License:        (GPL-2.0-only OR GPL-3.0-only) AND MIT
Group:          Productivity/Networking/Other
URL:            https://www.transmissionbt.com/
Source0:        https://github.com/transmission/transmission/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        README.openSUSE
Source98:       transmission-user.conf
Source99:       %{name}.rpmlintrc
# PATCH-FEATURE-OPENSUSE harden_transmission-daemon.service.patch
Patch0:         harden_transmission-daemon.service.patch
BuildRequires:  alts
BuildRequires:  cmake
BuildRequires:  fdupes
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  gettext-tools
BuildRequires:  libb64-devel
BuildRequires:  libcurl-devel >= 7.28.0
BuildRequires:  libdeflate-devel
BuildRequires:  libevent-devel >= 2.0.0
BuildRequires:  libminiupnpc-devel
BuildRequires:  libpsl-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig
BuildRequires:  sysuser-tools
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
BuildRequires:  cmake(Qt5LinguistTools) >= %{qt5_version}
BuildRequires:  cmake(Qt5Network) >= %{qt5_version}
BuildRequires:  cmake(Qt5Svg) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
BuildRequires:  pkgconfig(giomm-2.68) >= %{glibmm_version}
BuildRequires:  pkgconfig(glibmm-2.68) >= %{glibmm_version}
BuildRequires:  pkgconfig(gtkmm-4.0) >= 4.10.0
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib) >= 1.2.3
Requires:       %{name}-common = %{version}
Requires:       alts
Provides:       %{name}-ui = %{version}
%if %{with ninja}
BuildRequires:  ninja
%endif
%if %{with webui}
BuildRequires:  npm >= 8.1.307
%endif

%description
Transmission is a BitTorrent client. It has GTK+ and Qt GUI clients,
a daemon for servers and headless use, and both can be remote
controlled by HTTP and the terminal. It supports Local Peer
Discovery, DHT, µTP, PEX and magnet links.

%package -n system-user-transmission
Summary:        System user and group transmission
BuildArch:      noarch
%sysusers_requires

%description -n system-user-transmission
System user for use by the transmission service

%package gtk
Summary:        GTK client for the "transmission" BitTorrent client
Group:          Productivity/Networking/Other
Requires:       %{name}-common = %{version}
Requires:       alts
# For canberra-gtk-play binary
Requires:       canberra-gtk-play
Provides:       %{name}-ui = %{version}

%description gtk
Transmission is a BitTorrent client. It has GTK+ and Qt GUI clients,
a daemon for servers and headless use, and both can be remote
controlled by HTTP and the terminal. It supports Local Peer
Discovery, DHT, µTP, PEX and magnet links.

This package contains a graphical user interface to transmission.

%package qt
Summary:        Qt interface for the "transmission" BitTorrent client
Group:          Productivity/Networking/Other
Requires:       %{name}-common = %{version}
Requires:       alts
Provides:       %{name}-ui = %{version}

%description qt
Transmission is a BitTorrent client. It has GTK+ and Qt GUI clients,
a daemon for servers and headless use, and both can be remote
controlled by HTTP and the terminal. It supports Local Peer
Discovery, DHT, µTP, PEX and magnet links.

This package contains a graphical user interface to transmission.

%package common
Summary:        Common data for the "transmission" BitTorrent client
Group:          Productivity/Networking/Other
Requires:       %{name}-ui = %{version}
Requires:       alts
BuildArch:      noarch

%description common
Transmission is a BitTorrent client. It has GTK+ and Qt GUI clients,
a daemon for servers and headless use, and both can be remote
controlled by HTTP and the terminal. It supports Local Peer
Discovery, DHT, µTP, PEX and magnet links.

%package daemon
Summary:        Daemon for the "transmission" BitTorrent client
Group:          Productivity/Networking/Other
%{?systemd_requires}

%description daemon
Transmission is a BitTorrent client. It has GTK+ and Qt GUI clients,
a daemon for servers and headless use, and both can be remote
controlled by HTTP and the terminal. It supports Local Peer
Discovery, DHT, µTP, PEX and magnet links.

%lang_package -n %{name}-gtk
%lang_package -n %{name}-qt

%prep
%autosetup -p1
# We can't just pass -DINSTALL_DOC=OFF to cmake, as this also disables the man pages
sed -i 's/if(INSTALL_DOC)/if(FALSE)/' CMakeLists.txt
cp %{SOURCE1} .

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
export CXX=g++-13
%endif
# Turning INSTALL_DOC off breaks the package because it doesn't install
# transmission.1 manpage, argh!
%cmake \
    -D ENABLE_CLI=ON \
    -D ENABLE_GTK=ON \
    -D ENABLE_QT=ON \
    -D ENABLE_WEB=%{webui_opt}
%cmake_build

%sysusers_generate_pre %{SOURCE98} transmission system-user-transmission.conf

%install
%cmake_install

%find_lang %{name}-gtk %{?no_lang_C}
%find_lang transmission transmission-qt.lang --with-qt --without-mo %{?no_lang_C}
%suse_update_desktop_file transmission-gtk
%suse_update_desktop_file transmission-qt

# The installation scripts don't install the Systemd service file for some
# reason.
install -v -m 0644 daemon/transmission-daemon.service \
    -D -t %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_localstatedir}/lib/transmission

# fix doc
rm -rf %{buildroot}%{_datadir}/doc/transmission

# alternatives - create binary symlink
ln -s %{_bindir}/alts %{buildroot}%{_bindir}/%{name}

# alternatives - create directory
mkdir -p %{buildroot}%{_datadir}/libalternatives/%{name}

# alternatives - create 'cli' configuration file
cat > %{buildroot}%{_datadir}/libalternatives/%{name}/5.conf <<EOF
binary=%{_bindir}/%{name}-cli
man=%{name}-cli.1
EOF

# alternatives - create 'gtk' configuration file
cat > %{buildroot}%{_datadir}/libalternatives/%{name}/15.conf <<EOF
binary=%{_bindir}/%{name}-gtk
man=%{name}-gtk.1
EOF

# alternatives - create 'qt' configuration file
cat > %{buildroot}%{_datadir}/libalternatives/%{name}/10.conf <<EOF
binary=%{_bindir}/%{name}-qt
man=%{name}-qt.1
EOF

install -D -m 0644 %{SOURCE98} %{buildroot}%{_sysusersdir}/system-user-transmission.conf

%pre -n system-user-transmission -f build/transmission.pre

%files
%doc docs/* news/* AUTHORS README.md README.openSUSE
%doc extras/send-email-when-torrent-done.sh extras/encryption.txt
%doc extras/extended-messaging.txt
%license COPYING
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-create
%{_bindir}/%{name}-edit
%{_bindir}/%{name}-remote
%{_bindir}/%{name}-show
%{_mandir}/man1/%{name}-cli.1%{?ext_man}
%{_mandir}/man1/%{name}-create.1%{?ext_man}
%{_mandir}/man1/%{name}-edit.1%{?ext_man}
%{_mandir}/man1/%{name}-remote.1%{?ext_man}
%{_mandir}/man1/%{name}-show.1%{?ext_man}
%dir %{_datadir}/libalternatives/%{name}
%{_datadir}/libalternatives/%{name}/5.conf

%files daemon
%doc docs/* news/* AUTHORS README.md README.openSUSE
%doc extras/send-email-when-torrent-done.sh extras/encryption.txt
%doc extras/extended-messaging.txt
%license COPYING
%{_bindir}/%{name}-daemon
%{_mandir}/man1/%{name}-daemon.1%{?ext_man}
%{_unitdir}/%{name}-daemon.service
%attr(-,transmission,transmission)%{_localstatedir}/lib/transmission/

%files gtk
%doc docs/* news/* AUTHORS README.md README.openSUSE
%doc extras/send-email-when-torrent-done.sh extras/encryption.txt
%doc extras/extended-messaging.txt
%license COPYING
%{_bindir}/%{name}-gtk
%{_datadir}/applications/%{name}-gtk.desktop
%{_mandir}/man1/%{name}-gtk.1%{?ext_man}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}-gtk.metainfo.xml
%dir %{_datadir}/libalternatives/%{name}
%{_datadir}/libalternatives/%{name}/15.conf

%files qt
%doc docs/* news/* AUTHORS README.md README.openSUSE
%doc extras/send-email-when-torrent-done.sh extras/encryption.txt
%doc extras/extended-messaging.txt
%license COPYING
%{_bindir}/%{name}-qt
%{_datadir}/applications/%{name}-qt.desktop
%{_mandir}/man1/%{name}-qt.1%{?ext_man}
%dir %{_datadir}/libalternatives/%{name}
%{_datadir}/libalternatives/%{name}/10.conf

%files common
%{_bindir}/%{name}
%{_datadir}/icons/*/*/apps/%{name}*.svg
# English translations should be generally available
%{_datadir}/locale/en_AU/LC_MESSAGES/
%{_datadir}/locale/en_CA/LC_MESSAGES/
%{_datadir}/locale/en_GB/LC_MESSAGES/
%{_datadir}/%{name}/translations/transmission_en.qm
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/public_html
%{_datadir}/%{name}/public_html/*

%files gtk-lang -f %{name}-gtk.lang
# English translations should be generally available
%exclude %{_datadir}/locale/en_AU/LC_MESSAGES/
%exclude %{_datadir}/locale/en_CA/LC_MESSAGES/
%exclude %{_datadir}/locale/en_GB/LC_MESSAGES/

%files qt-lang -f %{name}-qt.lang
%dir %{_datadir}/%{name}/translations
# English translations should be generally available
%exclude %{_datadir}/%{name}/translations/transmission_en.qm

%files -n system-user-transmission
%{_sysusersdir}/system-user-transmission.conf

%changelog
* Thu May 30 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.0.6:
  + Improved parsing HTTP tracker announce response. (#6223)
  + Fixed 4.0.0 bug that caused some user scripts to have an
    invalid TR_TORRENT_TRACKERS environment variable. (#6434)
  + Fixed 4.0.0 bug where alt-speed-enabled had no effect in
    settings.json. (#6483)
  + Fixed 4.0.0 bug where the GTK client's "Use authentication"
    option was not saved between's sessions. (#6514)
  + Fixed 4.0.0 bug where the filename for single-file
    torrents aren't sanitized. (#6846)
  + Fixed 4.0.0 bug where piece size description text and slider
    state in torrent creation dialog are not always up-to-date.
  + Fixed build when compiling with GTKMM 4. (#6393)
  + Added the launchable desktop-id to metainfo files. (#6779)
  + Fixed build when compiling on BSD. (#6812)
  + Fixed a 4.0.0 bug where the infinite ratio symbol
    was displayed incorrectly in the WebUI. (#6491, #6500)
  + Fixed layout issue in speed display. (#6570)
  + General UI improvement related to filterbar and fixes
    download/upload speed info wrap. (#6761)
  + Fixed a couple of logging issues. (#6463)
* Tue Apr 16 2024 Max Lin <mlin@suse.com>
- Build with gcc13 on Leap 15
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with recent cmake macro change (DOCDIR): do not install
  the documentation using cmake, as we already do so using %%doc.
  Change if(INSTALL_DOC) to if(FALSE) in CMakeLists.txt. The more
  obvious option of passing -DINSTALL_DOC=OFF is ot viable, as that
  also disables installing the man pages.
* Wed Feb 14 2024 Martin Schreiner <martin.schreiner@suse.com>
- Migrate from update-alternatives to libalternatives (bsc#1219107).
* Tue Feb  6 2024 Matej Cepl <mcepl@cepl.eu>
- Add correct creation of the transmission user/group (needed by the
  latest RPM 4.19).
- Remove now useless Provides in the daemon subpackage.
* Sat Feb  3 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Have transmission-daemon provide user(transmission) and
  group(transmission): the user/group are generated in the pre
  scriptlet using useradd/groupadd.
* Wed Jan 10 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to version 4.0.5:
  + Fixed 4.0.0 bug where the IP address field in UDP announces were
    not encoded in network byte order.
  + Fixed a bug that incorrectly escaped JSON strings in some locales.
  + Fixed 4.0.4 decreased download speeds for people who set a low
    upload bandwidth limit.
  + Fixed bug that prevented editing trackers on magnet links.
  + Fixed HTTP tracker announces and scrapes sometimes failing after
    adding a torrent file by HTTPS URL.
  + In RPC responses, change the default sort order of torrents
    to match Transmission 3.00.
  + Fixed tr_sys_path_copy() behavior on some Synology Devices.
  + Fix: only append .added suffix to watchdir files.
  + Fixed crash when opening torrent file from "Recently used"
    section in GTK 4.
* Fri Nov 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.4:
  + Fixed bug in sending torrent metadata to peers.
  + Avoid unnecessary heap memory allocations.
  + Fixed filename collision edge case when renaming files.
  + Fixed locale errors that broke number rounding when displaying
    statistics, e.g. upload / download ratios.
  + Always use a fixed-length key query in tracker announces. This
    isn't required by the spec, but some trackers rely on that
    fixed length because it's common practice by other BitTorrent
    clients.
  + Fixed potential Windows crash when getstdhandle() returns NULL.
  + Fixed 4.0.0 bug where the port numbers in LDP announces are
    sometimes malformed.
  + Fixed a bug that prevented editing the query part of a tracker
    URL.
  + Fixed a bug where Transmission may not announce LPD on its
    listening interface.
  + Made small performance improvements in libtransmission.
  + Qt Client:
  - Fixed torrent name rendering when showing magnet links in
    compact view.
  - Fixed bug that broke the "Move torrent file to trash"
    setting.
  - Fixed Qt 6.4 deprecation warning.
  - Fixed poor resolution of Qt application icon.
  + GTK Client: Fixed missing 'Remove torrent' tooltip.
  + Web Client:
  - Don't show null as a tier name in the inspector's tier list.
  - Fixed truncated play / pause icons.
  - Fixed overflow when rendering peer lists and made speed
    indicators honor prefers-color-scheme media queries.
  - Made the main menu accessible even on smaller displays.
  + transmission-cli:
  - Fixed "no such file or directory" warning when adding a
    magnet link.
  - Fixed bug that caused the wrong decimal separator to be used
    in some locales.
  + transmission-remote: Fixed display bug that failed to show some
    torrent labels.
  + Everything Else:
  - Ran all PNG files through lossless compressors to make them
    smaller.
  - Fixed potential build issue when compiling on macOS with gcc.
* Fri May  5 2023 Emiliano Langella <emiliano.langella@suse.com>
- Fix transmission-daemon missing /var/lib/transmission
* Sat Apr 15 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 4.0.3:
  + Fix 4.0.2 higher CPU load while downloading (a regression).
  + Fix 4.0.0 bug where the torrentGet RPC method returned wrong
    trackerStats.tier values.
  + Fix 4.0.0 HTTP announce behavior with bind-address-ipv*
    settings.
  + Fix 4.0.0 bug in code that detects the computer's IPv6 support.
  + Silenced 4.0.0 minor log warnings for cross_seed_entry and uid
    entries in torrent files.
  + When adding a duplicate torrent via the RPC API, the return
    value now matches Transmission 3's return value.
  + Fix use of metainfo display-name as a fallback name.
  + Updated torrent Peer ID generation to happen once per session,
    even for public torrents.
  + GTK client:
  - Fix 4.0.0 preferences dialog being too large for small
    displays.
  - Fix 4.0.0 regression of percents, speeds, sizes, etc, not
    being i18nized properly.
  + Daemon: Set the log level sooner at startup to ensure events
    aren't missed.
  + Fix 4.0.0 bug in the display of how much of a torrent has been
    downloaded.
  + Documentation improvements.
- Drop merged-upstream patch:
  9fc0e4ff6186e3aee3d3350e9f1b062aa6e161fe.patch
* Mon Mar 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 9fc0e4ff6186e3aee3d3350e9f1b062aa6e161fe.patch: Fix:
  disable-deprecated by default for end users (needed due to new
  deprecation in gtkmm).
* Thu Mar 16 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.0.2:
  + Highlights:
  - Fixed 4.0.1 bug where some torrents thought they were
    magnet links.
  - Fixed 4.0.0 bug where download speed limits were ignored for
    uTP peers.
  - Fixed 4.0.0 bug using announce-list when creating
    single-tracker private torrents.
  + All platforms:
  - Restored support for path.utf-8 keys in torrent info dictionaries.
  - Fixed value of TR_TIME_LOCALTIME environment variable in
    torrent scripts.
  - Limited in-kernel file copying to 2 GiB blocks at a time to avoid
    potential issues with CIFS mounts.
  - Simplified filename info in log messages.
  - Fixed std::clamp() assertion failures.
  - Fixed small error calculating protocol overhead when receiving
    peer messages.
  - Fixed incorrect escaping of non-BMP characters when
    generating JSON.
  - Fixed 4.0.0 crash when receiving malformed piece data from peers.
  - Fixed 4.0.0 potential crash when downloading from webseeds.
  - Improved handling of the leechers param in trackers'
    announce responses.
  - Fixed 4.0.0 regression that stopped increasing the download
    priority of files' first and last pieces. These pieces are
    important for making incomplete files previewable / playable
    while still being downloaded.
  - Fixed display of IPv6 tracker URLs.
  - Fixed code that could stop being interested in peers that
    have pieces we want to download.
  - Improved sanity checking of magnet links added via RPC.
  - Fixed a misleading error message when Transmission is unable to
    write to the incomplete-dir.
  - Worked around an older libdht bug that could provide
    invalid peer info.
  - Restored RPC torrentGet.wanted return value
    to match 3.00 behavior.
  + QT client:
  - Ensured that "Open File" opens the torrent's folder for
    multi-file torrents.
  - Fixed 4.0.0 bug that prevented batch-adding trackers to
    multiple torrents at once.
  - Fixed per-torrent ratio display in main window.
  + GTK client:
  - Fixed 4.0.0 ignoring -m/--minimized command line option.
  - Fixed assertion failure in the progress display when creating
    a new torrent.
  + Web client:
  - Fixed minor UI bugs, e.g. layout and control alignment.
  - Fixed 4.0.0 bug that that failed to save alternate speed begin/end
    settings changes.
  - Improved colors in both light & dark mode.
  + Daemon:
  - Made the "unrecognized argument" error message more readable.
  + transmission-remote:
  - Fixed a spurious error message when adding magnet links.
* Thu Feb 23 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 4.0.1:
  + Issues fixed:
  - Poor speed and some checksums being incorrectly marked as
    failed in somes torrents.
  - Beachballing / jank.
  - Blocklists using more memory than necessary.
  - Failure to migrate magnet links from Transmission 3.
  - Many other fixes.
- Changes from version 4.0.0:
  + Added many performance improvements, and numerous bugfixes.
  + The entire codebase has been migrated from C to C++.
  + The remote control GUIs (transmission-qt and transmission-web)
    now use the RPC API "table" mode, resulting in smaller payloads
    / less bandwidth use.
  + Added support for GTK 4, and both Qt5 and Qt6.
  + The GTK client has been ported to gtkmm.
  + New Features:
  - Support for using BitTorrent v2 and hybrid torrents.
  - Users can now set "default" trackers that can be used to
    announce all public torrents.
  - Newly-added seeds can start immediately and verify pieces on
    demand now.
  - Added an option to omit potentially-identifying information
    (e.g. User-Agent and date created) when creating new
    torrents.
  - The Web client has been rewritten and now supports mobile
    use.
  - When creating new torrents, users can now specify the piece
    size.
  - IPv6 blocklists are now supported.
  - Dozens of other new features.
  + Fix small scrape/announce packet size that could trip SYN flood
    detection on some systems.
  + Remove the 1024 open files limit previously required by how
    libcurl was used.
  + Add configurable anti-brute force settings.
  + Fetch metadata of stopped magnets.
  + Stop logging excessive error messages after they repeat too
    many times.
  + The web client has been given a major overhaul.
  + User-visible highlights include:
  - Mobile is now fully supported.
  - Added fullscreen support on mobile.
  - Better support for dark mode.
  - Added mime icons to the torrent list.
  - Improved theme consistency across the app.
- Port build system from Autotools to CMake: replace libtool build
  requirement with cmake and ninja; replace Autotool macros with
  CMake's.
- Add explicit build requirement on CMake modules: Qt5Gui,
  Qt5LinguistTools, Qt5Network, Qt5Svg, and Qt5Widgets.
- Drop libqt5-linguist-devel, now that its CMake module is being
  used instead.
- Use our own libdeflate as build requirement instead of the
  bundled one.
- Replace openssl-devel with the more reliable pkgconfig(openssl).
- Replace intltool build requirement with gettext-tools.
- Replace glib-2.0 and gtk+-3.0 with giomm-2.68, glibmm-2.68, and
  gtkmm-4.0 pkgconfig modules following code base switch from C to
  C++.
- Drop libappindicator3-devel build requirement. AppIndicator is no
  longer supported.
- Drop fdupes build requirement/macro. There isn't duplicate files
  anymore.
- Drop no longer needed %%desktop_database_post and
  %%icon_theme_cache_post macros targeted at pre-Leap openSUSE/SUSE
  releases.
- Drop no longer needed patches:
  transmission-hybrid-torrent-length.patch, and
  transmission-3.00-openssl-3.patch.
- Refresh harden_transmission-daemon.service.patch patch with
  Quilt.
- Drop transmission-qt.desktop source file favoring the one
  provided by upstream.
- Add transmission.rpmlintrc file to filter the "file-not-in-%%lang"
  warning, since we are excluding the English translations from the
  lang sub-packages and packaging them in the common sub-package
  instead.
* Sun Feb  5 2023 Luca Beltrame <lbeltrame@kde.org>
- Apply downstream patch from Gentoo to fix a crash with openSSL 3
  (boo#1207914):
  * transmission-3.00-openssl-3.patch
* Wed Jan 25 2023 Michael Vetter <mvetter@suse.com>
- boo#1207555: Transmission can't open Bittorrent v2 torrents
  Add transmission-hybrid-torrent-length.patch
* Sun Apr  3 2022 Stephan Kulow <coolo@suse.com>
- Do not run autoreconf - not patching any input files
  and intltool is broken with autoreconf of 2.71
* Thu Nov 25 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_transmission-daemon.service.patch
* Thu Nov  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.16: move installation of translations from
  %%build to %%install section.
* Fri May 29 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to transmission 3.00:
  + Common:
  - Allow the RPC server to listen on an IPv6 address.
  - Change TR_CURL_SSL_VERIFY to TR_CURL_SSL_NO_VERIFY and enable
    verification by default.
  - Go back to using hash as base name for resume and torrent
    files.
  - Handle "fields" argument in "session-get" RPC request.
  - Limit the number of incorrect authentication attempts in
    embedded web server to 100 to prevent brute-force attacks.
  - Set idle seed limit range to 1..40320 (4 weeks tops) in all
    clients.
  - Add Peer ID for Xfplay, PicoTorrent, Free Download Manager,
    Folx, Baidu Netdisk torrent clients.
  - Announce INT64_MAX as size left if the value is unknown.
  - Add TCP_FASTOPEN support.
  - Improve ToS handling on IPv6 connections.
  - Abort handshake if establishing DH shared secret fails.
  - Don't switch trackers while announcing.
  - Maintain a "session ID" file (in temporary directory) to
    better detect whether session is local or remote.
  - Change torrent location even if no data move is needed.
  - Support CIDR-notated blocklists.
  - Update the resume file before running scripts.
  - Make multiscrape limits adaptive.
  - Add label support to libtransmission and transmission-remote.
  - Parse session-id header case-insensitively.
  - Sanitize suspicious path components instead of rejecting
    them.
  - Add support for mbedtls (formely polarssl) and wolfssl
    (formely cyassl), LibreSSL.
  - Fix building against OpenSSL 1.1.0+.
  - Fix a number of memory leaks (magnet loading, session
    shutdown, bencoded data parsing).
  - Bump miniupnpc version to 2.0.20170509.
  - Switch to submodules to manage (most of) third-party
    dependencies.
  + GTK:
  - Add queue up/down hotkeys.
  - Modernize the .desktop file.
  - Add AppData file.
  - Add symbolic icon variant for the Gnome top bar and.
    when the high contrast theme is in use.
  - Update file icon when its name changes.
  - Switch from intltool to gettext for translations.
  + QT:
  - Bump minimum Qt version to 5.2.
  - Fix dropping .torrent files into main window on Windows .
  - Fix prepending of drive letter to various user-selected paths
    on Windows.
  - Fix sorting by progress in presence of magnet transfers.
  - Fix .torrent file trashing upon addition.
  - Add queue up/down hotkeys.
  - Reduce torrent properties (file tree) memory usage.
  - Display tooltips in torrent properties (file tree) in case
    the names don't fit.
  - Improve UI look on hi-dpi displays.
  - Use session ID (if available) to check if session is local
    or not.
  - Use default (instead of system) locale to be more flexible.
  - Modernize the .desktop file.
  + Daemon:
  - Use libsystemd instead of libsystemd-daemon.
  - Harden transmission-daemon.service by disallowing privileges elevation.
  - Fix exit code to be zero when dumping settings.
  + Web Client:
  - Fix tracker error XSS in inspector.
  - Fix performance issues due to improper use of setInterval()
    for UI refresh.
  - Fix recognition of https:// links in comments field.
  - Fix torrent list style in Google Chrome 59+.
  - Show ETA in compact view on non-mobile devices.
  - Show upload file button on mobile devices.
  - Add keyboard hotkeys for web interface.
  - Disable autocompletion in torrent URL field.
- Remove transmission-3rdparty-no-download.patch,
  transmission-appdata.patch andRemove transmission-systemd.patch:
  merged upstream.
- Change build system from cmake to autoconf: replace
  %%cmake/%%cmake_build/%%cmake_install with
  %%configure/%%make/%%make_install.
* Fri May 22 2020 Martin Pluskal <mpluskal@suse.com>
- Use modern macros for cmake building
- Cleanup spec file with spec-cleaner
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Oct 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop transmission-daemon-systemd source: No longer needed, and
  does in fact lead to a problem for endusers to set own config for
  the daemon. Dropping fixes boo#1139004.
- Pass explicit ENABLE_DAEMON=ON and WITH_SYSTEMD=ON to cmake,
  ensure we build upstreams daemon and systemd support.
* Tue May 14 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added %%global WITH_APPINDICATOR 1 to enable missing appindicator
  support
* Wed Oct 10 2018 Marguerite Su <i@marguerite.su>
- fix boo#1111323 transmission-qt try to load translations from /usr/bin
  + upstream issue#736 recommends to use cmake instead of autotools
    because codes related to autotools are deprecated. Nowadays
    we manually install transmission-qt translations into /usr/
    share/qt5/ directory where is designed for official Qt project
    only, while cmake will install to the right location /usr/share/
    transmission/translations.
  + switch build time configuration from autotools to cmake
- refactored transmission-appdata.patch to cmake-oriented.
  + handle transmission-gtk.appdata.xml translations with
    intltool-merge which is used by upstream for desktop files
    in gtk/CMakeLists.txt
  + handle transmission-qt.appdata.xml installation in
    qt/CMakeLists.txt instead of in specfile, because anyway
    we binary patch the -gtk.appdata.xml.in, we'd better not
    binary patch one while add another one as Source. so the
    SOURCE4 is also dropped.
- add transmission-3rdparty-no-download.patch
  + transmission's cmake configuration will download and build
    some 3rd-party libraries that could not be found in system.
    we patch its ExternalProject_Add() method to avoid the download
    because there are already source codes for such 3rd-party
    libraries located in third-party directory. Also, our OBS
    build machine doesn't support downloading in the build VM.
- mark COPYING with %%license tag instead of %%doc tag
- add extras/{rpc-spec.txt,send-email-when-torrent-done.sh}
  as doc since upstream installs them as doc too
* Wed May  2 2018 bjorn.lie@gmail.com
- Update to version 2.94:
  + All Platforms:
  - Fix building against LibreSSL.
  - Fix building against mbedTLS.
  - Fix torrents ETA calculation.
  - Fix cross-compilation issues caused by miniupnpc
    configuration test.
  + Qt Client: Fix bad downloaded percentage in DetailsDialog.
  + Web Client:
  - Fix tracker error XSS in inspector (CVE pending).
  - Fix torrent name HTML-escaping in trackers inspector tab.
* Thu Mar 22 2018 jengelh@inai.de
- Remove marketing from description.
* Sun Feb 18 2018 avindra@opensuse.org
- Update to version 2.93:
  + Mitigate dns rebind attacks against daemon CVE-2018-5702).
  + Fix crash on handshake if establishing DH shared secret fails.
  + Fix crash when switching to next tracker during announcement.
  + Fix potential issue during password salt extraction in OOM
    situation.
  + Workaround glib_DEFUN- and glib_REQUIRE-related configuration
    issue.
  + Fix building against OpenSSL 1.1.0+.
- Drop 0001-transmission-build-against-openssl-1.1.0.patch: fixed
  upstream (commit id f91cf5a).
- Drop
  0002-Fix-coding-style-and-building-with-TR_LIGHTWEIGHT.patch:
  fixed upstream (commit id 8c8386a).
- Drop CVE-2018-5072.patch: fixed upstream (commit id cf7173df).
- Cleanup with spec-cleaner.
- Use https url.
- Use qmake/make_jobs macros for building qt binary.
* Wed Jan 17 2018 dimstar@opensuse.org
- Add CVE-2018-5072.patch (backported from
  gh#transmission/transmission#468):  Mitigate dns rebind attacks
  against daemon (boo#1075921, CVE-2018-5072).
- Conditionalize usage of desktop_database_post/postun macros to
  suse_version < 1500: recent versions use file triggers.
- Add %%check session: run make check.
* Wed Aug 23 2017 vcizek@suse.com
- Backport support for OpenSSL 1.1
  + Added patches:
    0001-transmission-build-against-openssl-1.1.0.patch.
    0002-Fix-coding-style-and-building-with-TR_LIGHTWEIGHT.patch.
* Tue Aug  8 2017 carmen@carmenbianca.eu
- boo#1052817 - Edit transmission-qt.desktop to handle magnet links
  (x-scheme-handler/magnet).
* Fri Dec  9 2016 dimstar@opensuse.org
- Add transmission-systemd.patch: Look for libsystemd instead of
  libsystemd-daemon. The modules have been merged since
  systemd 209.
* Thu Aug  4 2016 badshah400@gmail.com
- Add transmission-appdata.patch to add, translate and install
  metainfo files for gtk application.
- Patch touches autotool files, add BuildRequires on libtool and
  run autoreconf -fi before ./configure; workaround an issue where
  aclocal fails due to "won't overwrite defined macro:
  glib_DEFUN".
- Add and install metainfo for transmission-qt as a separate
  source file.
* Mon Mar  7 2016 zaitor@opensuse.org
- Update to version 2.92:
  + Mac Client: Build OSX.KeRanger.A ransomware removal into the
    app.
- Changes from version 2.91:
  + All Platforms:
  - Fix Makefile.am to include Windows patches into source
    archive.
  - Fix miniupnpc script to handle spaces and other special chars
    in paths.
  + Mac Client:
  - Prevent crash during group rules removal in some cases.
  - Fix failure to remove seeding completion notifications from
    notification center.
  - Show main window and scroll to torrent on notification click.
  - Fix issue on Yosemite where peers view didn't occupy all the
    available space when web seed view was hidden.
  + Qt Client: Fix existing running instance detection and torrents
    delegation when using DBus.
  + Daemon:
  - Fix building on Windows x86.
  - Add `--blocklist-update` argument description to
    transmission-remote man page.
  - Use `-rad` as short form of `--remove-and-delete` option in
    transmission-remote.
* Mon Feb 29 2016 dimstar@opensuse.org
- Update to version 2.90:
  + All Platforms:
  - Fix renaming torrent files with common prefix.
  - Fix some more thread safety bugs in the tr_list datatype.
  - Fix infinite loop when removing torrent data.
  - Add support for CyaSSL/WolfSSL and PolarSSL cryptographic
    backends; bump OpenSSL minimum to v0.9.7.
  - Initial CMake build system support.
  - Many improvements to support Windows builds with MSVS and
    MinGW; drop XP/2003 support, only Vista and up now.
  - Allow building against system UTP and DHT libraries.
  - Fix several memory leaks and buffer overflows.
  - Support miniupnpc API v14.
  - Fix "prefetch-enabled" value type in settings.json (boolean
    instead of integer).
  - Fix some issues discovered by static analysis (cppcheck,
    coverity).
  - Fix invalid JSON encoding for non-printable characters.
  - Fix multi-threaded locale use when encoding/decoding JSON
    data.
  - Fix encrypted communication with libevent 2.1+.
  - Prevent completed pieces modification by webseeds.
  - Require absolute paths in RPC requests.
  - Fix and unify torrent origin display in GTK+, Qt and web
    clients.
  - Fix crash on session shutdown (evdns_getaddrinfo_cancel).
  - Retry if RPC server fails to bind to specified address.
  - Improve error checking on metadata retrieval.
  - Improve UTF-8 validity checking (merge changes from LLVM).
  - Don't build transmission-cli by default (it's long
    deprecated).
  + GTK+ Client:
  - Fix overshoot and undershoot indicators display with GTK+
    3.16+ in main window.
  - Don't require DISPLAY if started with `--version` argument.
  + Qt Client:
  - Improve performance in Torrent Properties dialog for torrents
    with lots of files.
  - Prevent entering file renaming mode with mouse double-click.
  - Add context menu on files tab of Torrent Properties dialog
    resembling that of Mac client.
  - Remove torrent file from watch directory even if "show
    options dialog" is not set.
  - Use theme-provided icons in system tray and About dialog.
  - Fix initial watch directory scan.
  - Improve filter bar look and feel; lots of other small visual
    fixes; RTL layout fixes.
  - Show message to the user when duplicate torrent is being
    added.
  - Improve magnets handling in main window.
  - Display notifications via tray icon if D-Bus is not
    available.
  - Show notice on top of filtered torrents list; clear whole
    filter on notice double-click.
  - Add proper compiler flags to indicate C++11 use.
  - Fix translation files loading.
  + Daemon:
  - Run as service on Windows when in background mode.
  - Rework directory watching, add support for native mechanisms
    on BSD/Darwin (kqueue) and Windows (ReadDirectoryChanges).
  - Don't make assumptions of remote path validity in
    transmission-remote.
  + Web Client:
  - Content Security Policy enhancements.
  - Enable "resume now" for queued torrents.
  - Mark appropriate fields in preferences dialog as HTML5 number
    fields.
  - Update to jQuery 1.11.2, jQueryUI 1.11.4; use jQueryUI menus
    instead of custom ones.
  + Updated translations.
- Pass --enable-external-b64 to configure: use the system provided
  b64 library.
- Pass --enable-cli to configure: retain the (deprecated) CLI
  interface.
- Add pkgconfig(zlip) and libb64-devel BuildRequires: new
  dependencies.
- Drop transmission-miniupnp14.patch: fixed upstream.
* Mon Nov 30 2015 idonmez@suse.com
- Add transmission-miniupnp14.patch to fix compilation with
  miniupnpc API level 14
* Mon Jul 21 2014 dimstar@opensuse.org
- Add rctransmission-daemon symlink for convenience.
- Fix usage of update-alternatives.
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 2.84 (bnc#887079, CVE-2014-4909):
  + All Platforms: Fix peer communication vulnerability.
- Changes from version 2.83:
  + All Platforms:
  - Licensing change: the GNU GPLv2 code can now be used under
    GNU GPL v2 or v3.
  - Fix network hanging issues that could occur when both UTP and
    DHT were enabled.
  - Fix 2.82 file descriptor leak when importing a blocklist.
  - Disallow torrents that contain "/../" in the path.
  - Fix 2.82 bug that didn't retain peers between sessions.
  - Fix potential dangling memory error in UDP tracker DNS
    lookups.
  - Remember a torrent's "queued" state between Transmission
    sessions.
  - Updated third party libraries: DHT updated to v0.22;
    miniupnpc updated to v1.9.
  - Autoconf script fixes: better detection of ccache, minupnpc.
  - Fix the X-Transmission-Session-Id header to be valid with the
    SPDY protocol.
  - Fix thread safety bugs in the tr_list datatype.
  - When determining free disk space on NetBSD>=6, support its
    Quota feature.
  - Windows portability improvements.
  + GTK+ Client: Fix threading issue on shutdown.
  + Qt Client:
  - Fix toggle-downloading-by-pressing-spacebar in the file list.
  - Fix "Open URL" crash from dangling pointer.
  - Support launching downloaded files from inside Transmission.
  - On Windows, use native Windows icons.
  - Improved network status info and tooltip in the status bar.
  - Fix "Open Torrent" dialog crash in Qt 5.2.
  + Daemon:
  - On systemd systems, fix config reloading via
    'systemctl reload'.
  - Use libevent's event loop.
  - Fix discrepancy in curl SSL setup between tr-daemon and
    tr-remote.
  - Fix broken OS X build.
  + Web Client:
  - Support file renaming in the web client.
  - Fix incorrect torrent state being displayed for magnet links.
  - Make URLs in the torrent's comment field clickable (and
    sanitize them to prevent cross-scripting).
  + Mac client fixes.
- Change license to (GPL-2.0 or GPL-3.0) and MIT, following
  upstreams relicensing.
- Switch Qt build to Qt5:
  + Replqce libqt4-devel BuildRequires with libqt5-linguist and
    libqt5-qtbase-devel.
  + Change qmake calls to be qmake-qt5 and lrelease to be
    lrelease-qt5.
  + Drop transmission-qt4.patch: no longer required.
* Fri Aug  9 2013 dimstar@opensuse.org
- Update to version 2.82:
  + All Platforms:
  - Fix webseed crash.
  - Fix crash when adding UDP trackers whose host's canonical
    name couldn't be found.
  - Fix crash when sending handshakes to some peers immediately
    after adding a magnet link.
  - Fix crash when parsing incoming encrypted handshakes when the
    user is removing the related torrent.
  - Add safeguard to prevent zombie processes after running a
    script when a torrent finishes downloading.
  - Fix "bad file descriptor" error.
  - Queued torrents no longer show up as paused after exiting &
    restarting.
  - Fix 2.81 compilation error on OpenBSD.
  - Don't misidentify Tixati as BitTornado.
  + Mac Client:
  - Fix bug that had slow download speeds until editing
    preferences.
  + GTK+ Client:
  - Fix crash that occurred in some cases after using
    Torrent > Set Location.
  - Fix crash where on_app_exit() got called twice in a row.
  - Fix 2.81 compilation error on older versions of glib.
  - Can now open folders that have a '#' in their names.
  - Silence gobject warning when updating a blocklist from URL.
  + Qt Client:
  - Qt 5 support.
  + Web Client:
  - Fix syntax error in index.html's meta name="viewport".
  - Fix file uploading issue in Internet Explorer 11.
- Add transmission-qt4.patch: Revert the changes for Qt5, as we do
  not have it available yet.
* Fri Jul 19 2013 dimstar@opensuse.org
- Update to version 2.81:
  + All Platforms:
  - Fix 2.80 bug that showed the incorrect status for some peers.
  - Better handling of announce errors returned by some trackers.
  - Fix compilation error on Solaris.
  + GTK+ Client:
  - Fix minor memory leaks.
  - Remove OnlyShowIn= from the .desktop file.
  + Qt Client: Remove OnlyShowIn= from the .desktop file.
  + Daemon: Change the systemd script to start Transmission after
    the network's initialized.
  + Web Client: Slightly better compression of png files.
  + Mac client fixes.
* Sat Jun 29 2013 dimstar@opensuse.org
- Update to version 2.80:
  + All Platforms:
  - Support renaming a transfer's files and folders.
  - Remove the most frequent thread locks in libtransmission (ie,
    fewer beachballs).
  - Show the free disk space available when adding torrent.
  - Faster reading and parsing of local data files.
  - Better use of the OS's filesystem cache.
  - Lengthen the prefetch cache for data sent to peers.
  - Other small speedups.
  - Replace the previous JSON parser with jsonsl to resolve DFSG
    licensing issue.
  - Fix fails-to-build when compiling with
  - Werror=format-security.
  - Improved unit tests in libtransmission.
  - Tarballs are now released only in .xz format.
  + Mac Client:
  - Use VDKQueue for watching for torrent files.
  + GTK+ Client:
  - Simplify the tracker filter pulldown's interface (now matches
    the Qt client).
  - Synced preferences text & shortcuts.
  - Remove deprecated calls to gdk_threads_enter().
  - Silence a handful of console warnings.
  + Qt Client:
  - More efficient updates when receiving information from the
    server.
  - Add an option to play a sound when a torrent finishes
    downloading.
  - Add an option to start up iconified into the notification
    area.
  - Fix an issue with the tray icon preventing
    hibernation/logout.
  - Other CPU speedups.
  - Open the correct folder when clicking on single-file
    torrents.
  - Synced preferences text & shortcuts.
  - Fix non Latin-1 unit strings.
  + Daemon:
  - Add support for specifying recently-active torrents in
    transmission-remote.
  + Web Client:
  - Extend the cookie lifespan so that settings like sort order
    don't get lost.
  + Utils:
  - Support user-defined piece sizes in transmission-create.
- Replace systemd BuildRequires with pkgconfig(libsystemd-daemon)
  to match what configure is checking for.
- Drop transmission-fix-qt-translations-dir.patch: fixed upstream.
* Wed Mar  6 2013 nmo.marques@gmail.com
- Add transmission-daemon-systemd to sources
- Split transmission-daemon into sub-package, add systemd service
  and macros (service to be disabled by default)
- Create 'transmission' user to run transmission-daemon (dont run
  service as root).
* Tue Feb 26 2013 zaitor@opensuse.org
- Update to version 2.77:
  + All Platforms:
  - Fix 2.75 regression that broke JSON parsing of real numbers
    in locales that don't use '.' as a decimal separator.
  - Don't invalidate the OS's file cache when closing files.
  - Fix overflow error when setting speed limits above ~8589
    kB/s.
  - Generated magnet links didn't include webseeds.
  - Fix minor memory leaks when using webseeds.
  + GTK+ Client:
  - Minor pluralization fixes in the UI.
  - Fix folder mis-selection issue in the Preferences dialog.
  - Fix GTK+ console warnings on shutdown.
  + Qt Client:
  - Fix non Latin-1 symbol issue when showing file transfer
    speeds.
  - Fix issue when creating new torrents with multiple trackers.
  - Fix lost text selection in the properties dialog's 'comment'
    field.
  + Daemon: Fix documentation errors in the spec and manpages.
  + Web Client: Fix minor DOM leak.
  + CLI: Fix transmission-cli failure when the download directory
    doesn't exist.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 2.76:
  + All Platforms:
  - Better error logging when user-provided scripts can't be
    executed.
  - The "Time Remaining" property wasn't set for torrents with
    webseeds but no peers.
  - Fix rare error that created a directory name "$HOME".
  + GTK+ Client:
  - Fix sort-by-age regression introduced in 2.74.
  - The "Edit Trackers" window didn't resize properly due to a
    2.70 regression.
  - Raise the main window when presenting it from an App
    Indicator.
  + Qt Client:
  - Add magnet link support to transmission-qt.desktop.
  - Fix notification area bug that inhibited logouts & desktop
    hibernation.
  - Use the "video" icon when the torrent is an mkv or mp4 file.
  - Toggling the "Append '.part' to incomplete files' names" had
    no effect.
  - Fix display of the torrent name in the Torrent Options dialog
  - Fix cursor point bug in the filterbar's entry field.
  - Fix crash when adding a magnet link when Transmission was
    only visible in the system tray.
  - Fix free-memory-read error on shutdown.
  + Daemon:
  - Better watchdir support.
  - Documentation fixes in transmission-remote's manpage.
  + Web Client:
  - Fix indentation of the torrent list and toolbar buttons on
    mobile devices.
  + CLI:
  - If the Download directory doesn't exist, try to create it
    instead of exiting.
* Mon Dec 17 2012 vuntz@opensuse.org
- Update to version 2.75:
  + Mac-only fixes.
* Tue Dec 11 2012 vuntz@opensuse.org
- Update to version 2.74:
  + All Platforms:
  - Fix a bug that prevented IPv6 addresses from being saved in
    dht.dat
  - Better handling of magnet links that contain 'tr.x='
    parameters
  - Add filtering of addresses used for uTP peer connections
  - Fix detection of whether or not a peer supports uTP
    connections
  + Web Client:
  - Fix a multi-file selection bug
  - Fix bug where the upload and download arrows and rates would
    not appear for downloading torrents
  - Fix bug when displaying the tracker list
  + Mac fixes.
* Wed Oct 31 2012 dimstar@opensuse.org
- Update to version 2.73:
  + Mac: Fix crash on non-English localizations.
* Wed Oct 17 2012 dimstar@opensuse.org
- Update to version 2.72:
  + All Platforms:
  - Fix crash when adding magnet links with malformed webseeds.
  - Fix handling of magnet links' webseed URLs that contain
    whitespace.
  - Fix remaining time estimates of magnet links that have
    webseeds.
  - Show the webseed count in the torrent list when downloading
    from webseeds.
  + GTK+: When adding torrents by URL from the clipboard, handle
    whitespace in the link.
  + Qt: Fix dialog memory leaks.
  + Web Client: Minor interface fixes.
  + Mac fixes.
* Thu Sep 27 2012 dimstar@opensuse.org
- Update to version 2.71:
  + Mac: Fix crasher on 10.6 Snow Leopard
- Changes from version 2.70:
  + All Platforms:
  - Improved speed with the µTP protocol
  - Fix bug that caused some incoming encrypted peer connections
    to fail
  - Fix bugs with the speed limit scheduler
  - Fix crasher with magnet links
  + GTK+:
  - Require GTK+ 3.4
  + Qt:
  - Control speed limit from the icon tray
  - Improved behavior when clicking on torrents in the torrent
    list
  - Fix bug where torrent files were not deleted
  - Fix bug with unicode characters in the default location
  + Web Client:
  - The file inspector tab displays files nested under
    directories
  - Improved scrolling on iPad
  - Fix incorrectly rendered characters
  - Fix bug involving attempts to post notifications without
    permission
  - Mac fixes.
- Spec file cleanup using spec-cleaner.
* Sat Aug 25 2012 nekolayer@yandex.ru
- Add transmission-qt-lang package:
  + Enable build of translation files for transmission-qt
  + Add transmission-fix-qt-translations-dir.patch: set
    transmission translations dir to QT library translations dir.
* Tue Jul 24 2012 zaitor@opensuse.org
- Update to version 2.61:
  + GTK+:
  - Support startup notification.
  - Require GTK+ 3.
  + Qt:
  - Fix bug when opening the web client via the Preferences
    dialog.
  - Better opening of magnet links.
  - The Torrent File list now handles very long lists faster.
  - Fix i18n problem introduced in 2.60.
  + Web Client:
  - Close potential cross-scripting vulnerability from malicious
    torrent files.
  + Utils:
  - Add magnet link generation to the transmission-show command
    line tool.
  + Mac:
  - Fix crash when creating a torrent file on Lion or newer.
- Drop 0%%{?favor_gtk2} / BuildRequires: pkgconfig(gtk+-2.0), gtk2
  support dropped upstream.
- Cleanup spec by dropping a lot of unused %%if statements for
  versions of openSUSE we no longer build for.
* Fri Jul  6 2012 dimstar@opensuse.org
- Update to version 2.60:
  + All Platforms:
  - Fix issues when adding magnet links
  - Improved scraping behavior for certain trackers
  - Fix bug where cleared statistics might not save
  - Updated versions of miniupnpc and libuTP
  - Fixed compilation issues with Solaris and FreeBSD
  - Other minor fixes
  + Web Client:
  - Notification of downloading and seeding completion (requires
    browser support of notifications)
  - Re-add select all and deselect all buttons to the file
    inspector tab
  + Mac-specific changes.
  + Updated translations.
* Sat May 19 2012 zaitor@opensuse.org
- Update to version 2.52:
  + All Platforms:
  - Fix bug with zero termination of multiscrape strings.
  - Update the bundled libnatpmp and miniupnp port forwarding
    libraries.
  + GTK+:
  - Fix minor bug in Ubuntu app indicator support.
  + Mac-specific changes.
- Drop xz BuildRequires, since this comes for free in the
  buildsystem now.
* Mon Apr  9 2012 dimstar@opensuse.org
- Update to version 2.51:
  + All Platforms:
  - Update the bundled libnatpmp and miniupnp libraries for port
    forwarding
  - Add environment variable options to have libcurl verify SSL
    certs
  - Support user-specified CXX environment variables during
    compile time
  + GTK+:
  - Fix crash when adding torrents on systems without
    G_USER_DIRECTORY_DOWNLOAD
  - Honor the notification sound setting
  - Add a tooltip to files in the torrents' file list
  - Fix broken handling of the Cancel button in the "Open URL"
    dialog
  - Improve support for Gnome Shell and Unity
  - Catch SIGTERM instead of SIGKILL
  + Qt:
  - Progress bar colors are now similar to the Mac and Web
    clients'
  - Improve the "Open Folder" behavior
  + Web Client:
  - Fix global seed ratio progress bars
  - Fix sometimes-incorrect ratio being displayed in the
    Inspector
  - If multiple torrents are selected, show the aggregate info in
    the Inspector
  - Upgrade to jQuery 1.7.2
  + Daemon:
  - Show magnet link information in transmission-remote -i.
* Mon Feb 27 2012 dimstar@opensuse.org
- Conditionally use libminiupnpc-devel BuildRequires on openSUSE
  12.2 and later only. Previous openSUSE versions did not have the
  package and will make use of the miniupnp that is bundled with
  the transmission sources.
* Fri Feb 17 2012 vuntz@opensuse.org
- Add libminiupnpc-devel BuildRequires: use an external miniupnpc
  instead of a bundled copy. This needs a fix in our miniupnpc
  package to work, though.
- Remove libnotify-tools Requires from gtk subpackage: this is not
  needed anymore since transmission now uses dbus directly to
  create notifications.
* Tue Feb 14 2012 zaitor@opensuse.org
- Update to version 2.50:
  + All Platforms:
  - Fix crash when adding some magnet links.
  - Improved support for downloading webseeds with large files.
  - Gracefully handle incorrectly-compressed data from webseed
    downloads.
  - Fairer bandwidth distribution across connected peers.
  - Use less CPU when calculating undownloaded portions of large
    torrents.
  - Use the Selection Algorithm, rather than sorting, to select
    peer candidates.
  - Use base-10 units when displaying bandwidth speed and disk
    space.
  - If the OS has its own copy of natpmp, prefer it over our
    bundled version.
  - Fix Fails-To-Build error on Solaris 10 from use of mkdtemp().
  - Fix Fails-To-Build error on FreeBSD from use of alloca().
  - Fix Fails-To-Build error when building without a C++ compiler
    for libuT.
  + GTK+:
  - Fix regression that broke the "--minimized" command-line
    argument.
  - Instead of notify-send, use the org.freedesktop.Notifications
    DBus API.
  - Fix a handful of small memory leaks.
  + Qt:
  - Fix FTB when building without libuTP support on Debian.
  + Web Client:
  - Filtering by state and tracker.
  - Sorting by size.
  - Larger, easier-to-press toolbar buttons.
  - Fix the torrent size and time remaining in the inspector's
    details tab.
  - Bundle jQuery and the stylesheets to avoid third-party CDNs.
  - Upgrade to jQuery 1.7.1.
  - Fix runtime errors in IE 8, IE 9, and Opera.
  - Revise CSS stylesheets to use SASS.
  - Minor interface tweaks.
  + Daemon:
  - Fix corrupted status string in transmission-remote.
* Thu Oct 20 2011 dimstar@opensuse.org
- Update to version 2.42:
  + All Platforms:
  - Fix error connecting to UDP trackers from big-endian systems
  - Fix RPC error when editing UDP trackers
  - Fix build failure when a C++ compiler is not installed
  + Mac:
  - Fix a potential crash on 10.5 Leopard
  - Fix bugs with the tracker and file inspector tables
  + GTK+:
  - Support GTK+ 3.2
  - Fix crasher on systems not running DBus
  + Web Client
  - Fix bug which broke Opera support
  + Updated translations.
- Add conditional pkgconfig(gtk+-3.0) BuildRequires, based on
  favor_gtk2; in case favor_gtk2 evaluates to true, we stay with
  the existing gtk2-devel BuildRequires.
* Mon Oct 10 2011 vuntz@opensuse.org
- Update to version 2.41:
  + Fix crash on Mac.
* Sat Oct  8 2011 zaitor@opensuse.org
- Change notify-tools Requires to libnotify-tools (notify-tools
  doesn't exist...).
* Thu Oct  6 2011 vuntz@opensuse.org
- Update to version 2.40:
  + All Platforms:
  - Torrent queuing
  - Improved webseed support
  - Fix crash when removing a magnetized transfer
  - Fix adding transfers over RPC when a subfolder does not exist
  - Other minor fixes
  + GTK+:
  - Add GTK+ 3 support
  - Make popup notification and system sounds system-configurable
  - Add a settings option to hard-delete files instead of using
    the recycle bin
  + Qt:
  - Add popup notification for finished torrents
  - Fix non-UTF-8 display issue in the "New Torrent" dialog
  + Daemon:
  - SSL support in transmission-remote
  + Web Client:
  - Speed improvements
  - Add filtering by tracker
  - Allow preference changes on mobile devices
  - Allow compact view on mobile devices
  - Stop ratio functionality
  - Compact view interface improvements
  + Utils:
  - Fix transmission-edit bug when adding a tracker to a
    single-tracker torrent
  - Fix transmission-create bug when specifying a directory with
    a leading "./"
- Note that we can't use the GTK+ 3 support as the build system has
  not been updated for it.
- Add explicit glib2-devel BuildRequires.
- Remove dbus-1-glib-devel, libcanberra-devel, libnotify-devel
  BuildRequires: they're gone upstream.
- Add canberra-gtk-play Requires to gtk subpackage: transmission
  now uses the canberra-gtk-play binary.
- Add libnotify-tools Requires to gtk subpackage: transmission now
  uses the notify-send binary.
* Thu Jul 21 2011 vuntz@opensuse.org
- Update to version 2.33:
  + All Platforms:
  - Improved webseed support
  - Better support for moving and deleting files
  - Fix "Too many open files" bug
  - Apply blocklists towards DHT communication
  - Fix displayed availability
  + GTK+:
  - Remove deprecated GConf2 dependency
  + Qt:
  - Fix high CPU issues
  - Fix wrong torrent count on tracker filterbar
  + Updated translations.
- Remove gconf2-devel BuildRequires.
- Add dbus-1-glib-devel BuildRequires that was missing earlier, or
  was implicit before.
* Thu Jun 30 2011 dimstar@opensuse.org
- Update to version 2.32:
  + All Platforms:
  - Fix error caused by some "open-file-limit" configuration
    settings
  - Fix 2.30 problem seeding to some peers
  - Fix bug converting torrent file text contents to UTF-8
  - Better µTP support on systems running uClibc
  - Other small bug fixes
  + GTK+:
  - Fix 2.30 error opening torrents from a web browser
  - Remove GNOME desktop proxy support
  + Web Client:
  - Fix bug when adding torrents
  - Add torrents by info hash in the add dialog
  - Sorting by ratio
  - Allow drag-and-drop to add links
- Add xz BuildRequires to be able to decompress the tar.xz source.
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 2.31:
  + This release fixes a bunch of packaging issues in 2.30.
- Changes from version 2.30:
  + All Platforms
  - 265TP support
  - UDP tracker support
  - Multiscrape support
  - Download scarcest pieces first
  - The "lazy bitfield" feature has been superseded by the
    "Fast Extension" BEP6
  - Scripts are passed the environment
  + GTK+:
  - Added 256 x 256 icon
  - Register as a magnet link handler in the .desktop file
  + Web Client:
  - Peer and Network preferences
* Mon Apr  4 2011 dimstar@opensuse.org
- Allow to switch on appindicators based on Project Meta data
  (WITH_APPINDICATOR).
* Thu Mar 10 2011 dimstar@opensuse.org
- Update to version 2.22:
  + All Platforms:
  - Faster endgame
  - Fix bug where leechers might be disconnected while seeding in
    some situations
  - Fix 2.20 bug that sometimes showed inaccurate upload/download
    speeds
  - Support for unsorted blacklists
  - Fix IPv6 DHT
  - Re-add support to automatically close idle peers
  - Fix bug where the resume file did not save the time checked
    for the last piece
  + GTK+:
  - Fix setting individual idle seeding time
  + Qt:
  - Fix loading localizations on Linux
  + CLI:
  - Fix bandwidth display issue
  + Updated translations.
* Sat Feb 12 2011 dimstar@opensuse.org
- Update to version 2.21:
  + Fix compilation errors of 2.20 release
  + Updated translations
- Changes from version 2.20:
  + All Platforms:
  - Remember downloaded files when a drive is unplugged
  - File re-verification is no longer needed in some situations
  - Fix "Too many open files" error
  - Show the total downloading and seeding time per torrent
  - Fix webseeds
  - Better support for IPv6-only trackers
  - Add the ability to shutdown Transmission sessions via RPC
  - NAT-PMP and UPnP now also map the UDP port
  - Update the DHT code to dht-0.18
  - Faster parsing of bencoded data
  - Improve support for running scripts when a torrent finishes
    downloading
  - Fix reannounce interval when trackers return a 404 error
  - Fix checksum error on platforms running uClibc 0.9.27 or
    older
  - Fix memmem() errors on Solaris
  + GTK+:
  - Add "Add" and "Remove" buttons to the tracker list
  - Add filesize column to the files list
  - Several minor bugfixes and interface improvements
  + Qt:
  - Accept info_hash values in the "Add url..." dialog
  + Daemon:
  - Add "reannounce to tracker" option to transmission-remote
  - transmission-remote can now read auth info from environment
    variables
  - Fix configuration file bug with transmission-daemon running
    on Macs
  + Web Client:
  - Right-clicking a torrent now works with Firefox /
    Firegestures / Ubuntu
  + Utils:
  - Fix error when replacing substrings in tracker announce URLs
  - Webseeds are now displayed in transmission-show
- BuildRequire libevent-devel >= 2.0.0 to save build power if we
  do not have the package available.
- Remove lang workaround, bnc#659001.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Sun Jan  9 2011 vuntz@opensuse.org
- Use update-alternatives to provide /usr/bin/transmission, with
  alternatives being transmission-cli, transmission-gtk and
  transmission-qt:
  + Create the ghost files in %%install.
  + Add update-alternatives Requires(post/postun) to the three
    packages.
  + Call update-alterantives in %%post/%%postun of the three
    packages.
  + The priority order is: gtk, qt, cli.
- This makes the usage of transmission from the command line a bit
  more intuitive. Fix bnc#657450.
* Sat Dec 11 2010 vuntz@opensuse.org
- Remove some locales until bnc#659001 is fixed, to fix a build
  failure.
* Fri Dec 10 2010 vuntz@opensuse.org
- Update to version 2.13:
  + All Platforms:
  - Fix "No Announce Scheduled" tracker error
  - Fix build error on Solaris 10
  - Fix RPC documentation errors
  - Fix minor packaging errors
  + GTK+:
  - Unblur the statusbar icons
  - Fix truncation error in the Torrent Properties dialog
  + Qt:
  - Fix crash when opening the Torrent Properties dialog on
    magnet links
  - Fix "undo" error when making changes in the Torrent
    Properties dialog
  + Updated translations.
* Tue Nov 16 2010 badshah400@gmail.com
- Update to version 2.12:
  + All Platforms:
  - Make the blocklist URL user-configurable
  - Several minor bug fixes and CPU speed improvements
  - Use slightly less bandwidth in DHT messages
  - Fix 2.10 build issue on uClibc systems
  + GTK+:
  - Fix 2.11 crash when opening the Properties dialog on a magnet
    link torrent
  - Fix 2.00 regression which failed to inhibit hibernation on
    laptops
  + CLI:
  - Fix 2.10 crash
  + Web Client:
  - Upgrade to jQuery 1.4.3
  - Fix 2.11 regression when using the web client on IE7 or IE8
* Mon Oct 18 2010 vuntz@opensuse.org
- Update to version 2.11:
  + All Platforms:
  - Fix a 2.10 crash
  - Fix minor build issues on various platforms, particularly
    embedded systems
  - Fix issue when saving bencoded files on small hardware
    running uClibc
  - Fix minor rounding issue when displaying percentages
  - Fix the optimistic unchoke interval
  + GTK+:
  - Fix drag-and-dropping a magnet link
  - Fix hiding dialogs when hiding Transmission in the
    notification area
  + Qt:
  - Fix crash in the file tree
  + Daemon:
  - Fix missing status message when using "transmission-remote
  - -add"
  + Web Client:
  - Add Transmission website links to the action menu
* Fri Oct  1 2010 vuntz@opensuse.org
- Update to version 2.10:
  + All Platforms:
  - Support for automatically stopping idle seeding torrents
  - Small memory cache to reduce disk IO
  - gzip compression support added to the RPC server
  - Add support for a cookies.txt file
  - Minor CPU optimizations
  + GTK+:
  - Files and folders can be opened by clicking on them in the
    files list
  - Update the interface when session changes are made via RPC
  - Fix the Details dialog to fit on a netbook screen
  + Qt:
  - Tracker announce list editing
  - New filterbar
  - Improved display for showing a torrent's tracker announces
  - Better DBUS integration
  - Support adding torrents via drag-and-drop
  - Add Desktop Notification for added/complete torrents
  - Other minor improvements
  + Web Client:
  - Peer list added to the inspector
  - Compact view mode
  - Support filtering by active and finished
  - Support sorting by size
  + Daemon:
  - Allow the .pidfile location to be set in settings.json
  + Utils
  - New command-line utility "transmission-edit" for editing
    torrent files
  - New command-line utility "transmission-show" for viewing
    torrent files
  - New command-line utility "transmission-create" for creating
    torrent files
- Change the lang package to be transmission-gtk-lang instead of
  transmission-common-lang: apparently, only the GTK+ application
  is localized.
- Do not change transmission-gtk.desktop with
  %%suse_update_desktop_file: it's already perfectly fine.
- Update transmission-qt.desktop after renaming of qtr to
  transmission-qt.
* Sun Aug  8 2010 bjorn.lie@gmail.com
- Update to version 2.04:
  + All Platforms:
  - Fix display bug in tr_truncd()
  + GTK+:
  - Fix inaccurate "active torrent" counts in the filterbar
  - Fix display bug with magnet link names
  + Qt:
  - Fix crash when accessing a password-protected remote session
  + Web Client:
  - Fix bad redirect
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 2.03:
  + Fix bug on Mac version.
- Changes from version 2.02:
  + All Platforms:
  - Fix NAT-PMP port forwarding issue on some systems
  - Fix filename errors for torrents whose files are encoded in
    ISO-8859-1
  - Fix rare crash on shutdown
  - Fix the RPC server's redirect URL to allow HTTPS proxies like
    stunnel
  - Replace less-portable calls with posix nanosleep()
  + GTK+:
  - Fix crash when opening the Properties dialog on a magnet link
    without metainfo
  - Fix crash when removing multiple torrents at once
  - Allow individual torrents' download speed limits to be set to
    zero
  - Fix translation error with some error messages
  + Qt:
  - Fix CPU spike when opening the Properties dialog
  - Fix compilation issue with Qt < 4.5
* Fri Jul 16 2010 vuntz@opensuse.org
- Update to version 2.01:
  + All Platforms:
  - Better tracker announce management when completed torrents
    are moved from the incomplete directory
  - Speed up moving local data from one disk to another
  - Better parsing of nonstandard magnet links
  + GTK+:
  - Faster torrent file parsing
  - Fix the magnet link options dialog does not respect setting
  - Add an error popup if "Add URL" fails
  + Qt:
  - Fix crash after getting magnet torrent metadata
  - Fix torrent ratio goals
  - Fix "add torrent" dialog bug on KDE desktops that popped up
    previous torrents
  - Fix 2.00 bug that prevented multiple instances from being run
  - Fix remote mode bug that kept the torrent list from being
    shown
  - Support encryption settings in the preferences dialog
  - Use flagStr in the status field of the peer list
  - Request a full refresh when changing the session source
  - Fix the torrent list jumping to the top when a torrent is
    removed
  + Web Client:
  - Fix display bug caused by removal of a torrent hidden by the
    current filter
* Sat Jun 19 2010 admin@djscore.org
- Update to version 2.00:
  + All Platforms:
  - "Local Peer Discovery" for finding peers on the local network
  - Optimize download requests for the bandwidth available
  - Smarter heuristics when deciding the order to connect to
    peers
  - Faster verification of local data
  - Faster startup
  - Support more blocklist file formats
  - Use IEC standard units (KiB, MiB, GiB) instead of
    (KB, MB, GB)
  - Better handling of 404 tracker errors
  + GTK+:
  - New filterbar to filter by tracker, private/public, etc.
  - Compact View replaces Minimal View, taking up considerably
    less space
  - Show the Torrent Options dialog when adding magnet links
  - "Set Location" now supports moving multiple torrents at once
  - The Properties window now fits on low resolution screens
  - Add favicon support to the Properties dialog's Tracker tab
  + Qt:
  - Show the Torrent Options dialog when adding magnet links
  - Show all active trackers in the tracker display list
  - Show file sizes in the file tree
  - Added a confirm dialog when removing torrents
  - Properties and torrent options no longer jump around while
    editing
  - Allow setting locations for remote sessions
  - Miscellaneous UI fixes
  + Daemon:
  - Let users specify a script to be invoked when a torrent
    finishes downloading
  - Better support for adding per-torrent settings when adding
    a new torrent
  - Optional pidfile support
  - Option to start torrents paused
  - Option to delete .torrent files from watch directory
  + Web Client:
  - The context menu now works when multiple rows are selected
  - Show ETA for seeding torrents that have a seed ratio set
* Mon May  3 2010 dimstar@opensuse.org
- Update to version 1.93:
  + All Platforms:
  - Fix rare crash when some peers disconnected unexpectedly
  - Fix bug which didn't parse scheduled speed limit dates
    correctly
  - Fix bug that broke magnet links whose names contained slashes
  - Fix crash when updating the blocklist when the disk is full
  - Fix slow file preallocation on Unix systems not using
    ext3/ext4
  - Fix regression which broke the "bind-address-ipv4"
    configuration setting
  - For better security, Web client connctions are disabled by
    default
  - Upgrade to miniupnpc-1.4
  - Transmission builds out-of-the-box with Curl 7.15.5.
  + GTK+:
  - Use the size for the system tray icon
  + Qt:
  - Fix bug that crashed when removing more than one torrent at
    once
  - Fix bug when parsing the remote password from the command
    line
  - Add support for the "incomplete directory" in the preferences
    dialog
  - Don't show "time remaining" for paused torrents
  + Daemon:
  - Fix bug parsing RPC requests when setting which files to not
    download
  - Fix possible crash when using inotify for the daemon's
    watchdir
  - Fix bugs in the configure script
  - Fix bug updating the blocklist over RPC
  + Web Client:
    + Fix bug that broke the "reverse sort order" menu checkbox
- Drop transmission-no-dht.patch and remove --disable-dht from
  configure.
* Fri Mar 12 2010 dimstar@opensuse.org
- Update to version 1.92:
  + All Platforms:
  - Fix possible data corruption issue caused by data sent by bad
    peers during endgame
  - Fix potential buffer overflow when adding maliciously-crafted
    magnet links
  - Fix announces to IPv6 trackers
  - Fix DNS problems on some platforms, including Debian
  - Fix issues with the incomplete directory functionality
  - Fix port forwarding error on some routers by updating
    libnatpmp and miniupnp
  + GTK+:
  - Fix directory selection error in GTK+ 2.19
  - Small GUI improvements: HIG correctness, remove deprecated
    GTK+ calls, etc.
  + Daemon:
  - Fix 1.91 build error on Mac and FreeBSD
  - Standardize the daemon's watchdir feature to behave like the
    other clients'
  + Web Client
  - Statistics dialog
  - Fix error in "trash data & remove from list" that didn't
    trash all data
  - Fix display of ratios and time
  - Update to jQuery 1.4.2
- Pass RPM_OPT_FLAGS also the the qmake built Qt UI.
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 1.91:
  + All Platforms:
  - Fix 1.90 crash-on-startup bug that affected some users
  - Fix 1.90 bug that caused the "turtle mode" state to be
    forgotten between sessions
  - Fix 1.83 crash when adding a torrent by URL from an ftp
    source via the web client
  - For the BitTorrent spec's "downloaded=X" passage, use the de
    facto standard
* Wed Feb 17 2010 dimstar@opensuse.org
- Update to version 1.90:
  + All Platforms:
  - Add an option to disable the .part suffix for incomplete
    files
  - Add priority selector to GUI clients' add torrent windows
  - Fix 1.81 bug that broke HTTP requests to sites that gave HTTP
    301 redirects
  - Fix 1.8x bug in announcing "finished downloading" and
    "stopping" at the same time
  - Fix 1.8x bug in announcing partial seeds
  - Try harder to make announces finish, even if the tracker
    responds slowly
  - Fix bug that didn't honor download speed limits of 0
  - Use fallocate64() for fast file preallocation on systems that
    support it
  - Magnet link improvements
  - Don't let "Disk is full" errors cause loss of configuration
    files
  - Faster parsing of bencoded data, such as .torrent files
  + GTK+:
  - Give more helpful error messages if "Set Location" or "Add
    Magnet Link" fail
  - Add optional support for libappindicator
  - Minor build fixes
  + Daemon:
  - Add transmission-remote support for port testing and
    blocklist updating
  - Add transmission-daemon support for incomplete-dir, dht, and
    seedratio
  - If settings.json is corrupt, give an error telling where the
    problem is
  - Add option to specify where log messages should be written
  + Web Client:
  - Add a tracker tab to the inspector
  - Fix 1.8x display error when showing magnet link information
  + Qt:
  - Fix bug that prevented torrents from being added via web
    browsers
* Fri Jan 29 2010 vuntz@opensuse.org
- Update to version 1.83:
  + All platforms:
  - Fix announce error that caused uploads and downloads to
    periodically freeze
  - Fix announce timeout error that caused "no response from
    tracker" message
  - Fix "file not found" error message that stopped some torrents
  - Fix crash when adding new torrents via their ftp URL
  - Fix crash when receiving invalid request messages from peers
  - Fix error when updating the blocklist
* Sun Jan 24 2010 vuntz@opensuse.org
- Update to version 1.82:
  + The 1.81 announce did not contain the port number
- Changes from version 1.81:
  + All platforms:
  - Fix 1.80 bug that misparsed some magnet links
  - Fix 1.80 bug that caused startup to be very sluggish for some
    people
* Thu Jan 21 2010 vuntz@opensuse.org
- Update to version 1.80:
  + All platforms:
  - Add support for magnet links
  - Add support for trackerless torrents
  - Add optional "incomplete directory" where partial downloads
    are stored
  - Add .part to incomplete files' filenames
  - Find more peers by announcing to each tier in a torrent's
    tracker list, rather than only one
  - Fix vulnerability from maliciously-crafted torrent files that
    could overwrite other files
  - Improved IPv6 support
  - Improved PEX sharing with other peers
  - Faster management of large peer lists
  - DHT improvements to bootstrapping and IPv6
  - Newly-added torrents without local data don't wait in the
    "Verify Local Data" queue anymore
  - Add an OS hint to not cache local data during torrent
    verification
  - Use less CPU when making encrypted handshakes to peers
  - Better filtering of bad IP addresses
  - Fix bug that gave "too many open files" error messages
  - Fix bug that could crash Transmission on shutdown
  - Fix bug that could unpause or repause a torrent on startup
  - When uploading, improve disk IO performance by prefetching
    the data in batches
  - Portability fixes for embedded systems
  - Other small bug fixes and improvements
  + GTK+ frontend:
  - Support org.gnome.SessionManager interface for inhibiting
    hibernation
  - Added support for adding torrents by URL or magnet link
  - Add optional "download complete" sound using the XDG sound
    naming spec
  - When creating a torrent, make it easier to auto-add that new
    torrent
  - New statusbar "Ratio" icon
  - Fix minor memory leaks
  - GNOME HIG improvements
  + Daemon:
  - When running as a daemon, send log messages to syslog
  - Reload settings.json when receiving SIGHUP
  - transmission-remote now allows per-torrent speed limits to be
    set
  + Web Client:
  - Add speed limit "turtle mode" support
  - Double-clicking a torrent opens/closes the torrent inspector
  - Add "Start When Added" checkbox when adding torrents
  - Add Select All / Deselect All buttons to the file inspector
  - Add version information to the preferences dialog
  - Ensure the context menu goes away when clicking on torrents
  - Fix bug that obscured part of the context menu
- Add gconf2-devel and libcanberra-devel BuildRequires.
* Tue Jan  5 2010 mxwu@novell.com
- Update to version 1.77:
  + All Platforms:
  - Fix potential data loss by maliciously-crafted .torrent files
  - Fix minor build issues and packaging issues on various
    platforms
  - Fix 1.7x error that could unpause or repause a torrent on
    startup
  - Minor CPU speedups
  + GTK+
  - Fix crash on shutdown
  - Fix GIcon memory leak
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the fil locale for old versions of
  openSUSE.
* Thu Nov 19 2009 dimstar@opensuse.org
- Update to version 1.76:
  + All Platforms:
  - Fix potential data loss when moving torrents to where they
    already are
  - Fix minor protocol error that didn't send a port message to some peers
  - Fix minor manpage errors
  + Daemon:
  - Potential data loss when using "transmission-remote --find"
  - Fix ratio-limit bug on some uClibc systems
  - Fix invalid JSON "nan" error on optware
  + GTK:
  - Fix crash in the Preferences dialog when testing to see if
    the port is open
  - Fix crash on exit when a torrent's Properties dialog is open
  - Fix tracker address display error in the torrent Properties
    dialog
  - Fix tray menu's main window status when Transmission is
    started minimized
  - Fix broken SIGINT (ctrl-c) handling
  - Fix 1.61 build failure on systems with new versions of glib
    but older versions of gtk
  + Qt:
  - Fix crash when removing expired torrents from the display
  - Fix client from closing, rather than closing to the system
    tray, when clicking X
  - Cannot open a torrent in KDE4 with right-clicking
- Use upstream solution for transmission-no-dht.patch, from trunk.
* Sat Oct 10 2009 dimstar@opensuse.org
- Update to version 1.75:
  + All Platforms:
  - Don't wait so long on unresponsive trackers if there are
    other trackers to try
  - Adding corrupt/invalid torrents could crash Transmission
  - Fix 1.74 bug that caused a high CPU load on startup
  - Fix 1.74 bug that stopped multitracker if a single tracker
    sent an error message
  - Fix bug in converting other charsets to UTF-8
  - Handle HTTP redirects more gracefully
  - Faster verification of local data for torrents with small
    piece size
  - Fix 1.74 build error when compiling without DHT
  + GTK+:
  - Fix "sort by time remaining"
  - Fix the turtle toggle button on old versions of GTK+
  - Fix startup error if another copy of the Transmission GTK
    client is running
  - Fix clang build issue
- Refactored transmission-no-dht.patch, partially included by
  upstream.
* Sun Sep 27 2009 dimstar@opensuse.org
- Fix categories of transmission-qt, it appeared twice in the menu.
* Sat Sep  5 2009 dimstar@opensuse.org
- bnc#535391 - Add a desktop file for the Qt variant.
- Split the icons and webparts in a -common package, required by
  all variants.
- Rename the -lang package to -common-lang to reflect better where
  it belongs to.
- Obsolete transmission-lang by transmission-common.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 1.74:
  + All Platforms
  - Better data recovery in the case of an OS or Transmission
    crash
  - If a data file is moved, stop the torrent instead of
    redownloading it
  - Fix bug that didn't list some peers in the resume file and
    in PEX
  - More helpful torrent error messages
  - DHT now honors the bind-address-ipv4 configuration option
  - Fix Debian build error with miniupnpc
  - Fix Cygwin build error with strtold
  - Update to a newer snapshot of miniupnpc
  + Mac
  - 64-bit compatibility
  - Queuing system will not exclude transfers with tracker
    warnings
  - Links to original torrent files are no longer maintained
  - Fix bug where changing the global per-torrent peer connection
    limit did not affect the current session
  - Fix bug where changing settings through RPC would result in
    wrong values being saved for three fields
  + GTK+
  - Fix crash that occurred when adding torrents on some desktops
  - Synchronize the statusbar's and torrent list's speeds
  - Fix the Properties dialog's "Origin" field for multiple
    torrents
  + Qt
  - If Transmission was minimized, clicking on it the icon tray
    didn't raise it
  + Daemon
  - Speed Limit mode support added to transmission-remote
  - Add a "session stats" readout to transmission-remote
  +  Web Client
  - Progress bar shows seeding progress
  - Fix bug that displayed "%%nan" when verifying a torrent
  - "Pause All" only appeared to pause torrents with peers until
    refresh
  + Updated translations.
- Add transmission-no-dht.patch and --disable-dht in configure.
* Wed Aug 19 2009 beineri@opensuse.org
- Fix Name field of .desktop file and don't show up twice in menu.
* Sun Jul 19 2009 bjorn.lie@gmail.com
- Update to version 1.73:
  + All Platforms
  - Fix bug where user-configured peer limits could be exceeded
  - Use less memory in some high-peer situations
  - Better estimation of time left to download
  - Support supportcrypto and requirecrypto flags in http tracker
    announces
  - Update to newer snapshots of libnatpmp and miniupnpc
  - Make DHT a compile-time option
  + GTK+
  - Use GDK-safe versions of g_idle_add() and g_timeout_add*()
  - Save some space in GTK+ >= 2.16.0 by not building
    SexyIconEntry
  + Qt
  - Fix bug that crashed Qt client when setting alternative
    up/down speeds
  + Daemon
  - Add umask support
  + Web Client
  - Inspector and Add Torrent buttons for iPhone/iPod Touch
  - Add location field to inspector
  + CLI
  - Some torrent files created with transmission-cli were invalid
* Wed Jun 17 2009 vuntz@novell.com
- Update to version 1.72:
  + All Platforms
  - Fix 1.70 crash with assertion "tv->tv_usec >= 0"
  - Fix 1.70 crash with assertion "tr_peerIoSupportsFEXT(
    msgs->peer->io )"
  - Better DHT announce management
  - Fix error in reporting webseed counts via RPC
  - Better file preallocation on embedded systems
  + Mac
  - Fix problem where a small set of users could not add torrents
  + GTK+
  - Fix 1.70 crash when setting options in the Properties dialog
  - Fix a rare crash in desktop notifications
  - Can now sort the file list by priority, download, and
    completeness
  - Adding a torrent from a browser sometimes didn't work.
  - Various usability improvements
  + Daemon
  - Remote didn't always send the right Encoding header in
    requests
* Tue Jun  9 2009 vuntz@novell.com
- Update to version 1.71:
  + All Platforms
  - Fix 1.70 bug that caused high CPU use in high-peer swarms
  - Fix 1.70 build problems with DHT and libevent
  + Daemon
  - Fix watchdir issue on OSes that don't have inotify
  + GTK+
  - Fix 1.70 intltool build problem
  - Fix crash when the OS's stock mime-type icons are
    misconfigured
  - Handle very long torrent file lists faster
  + Web Client
  - Fix 1.70 bug where some torrents appeared to be duplicates
- Changes from version 1.70:
  + All Platforms
  - Distributed hash table (DHT) support for public torrents
  - Add option for moving and finding a torrent's data on the
    disk
  - JSON RPC messages can be ~85%% shorter, saving bandwidth and
    CPU
  - When available, use the system's copy of libevent instead of
    building one
  - Automatically pause torrents when verifying
  - Fix small bugs and memory leaks
  + Mac
  - Holding down the option key on launch will pause all
    transfers
  + Web Client
  - Big speed improvements, especially with large torrents
  - Fix 1.61 bug that broke adding torrents via the web client
  - Add the ability to upload multiple torrents at once
  - Torrents added by URL were always paused, regardless of
    preferences
  - Comments and announce addresses were cut off in the inspector
  - The "data remaining" field wasn't updated when the number
    reached 0
  - Smaller design adjustments
  + GTK+
  - Make it clearer that the status bar's ratio mode button is a
    button
  - Torrent comment box did not scroll, so long comments were
    partially hidden
  + Qt
  - Initial torrent list was sometimes incorrect
  - Add-torrent-and-delete-source deleted the source even if
    there was an error
  - Prefs dialog didn't show or modify "Stop seeding torrents at
    ratio"
- Add libevent-devel BuildRequires.
* Sun May 17 2009 vuntz@novell.com
- Update to version 1.61:
  + All Platforms
  - Close potential CSRF security hole for Web Client users
  - Fix locale error in the JSON parser
  + Qt
  - Various small bugfixes to the beta Qt client
  + Web Client
  - Fix 1.60 error when serving Web Client files on some embedded
    platforms
  - Add response header to allow clients to cache static files
  + Daemon
  - transmission-remote was unable to select torrents by their
    SHA1 hash
- Do not force CFLAGS and CXXFLAGS during compilation while they
  were set earlier.
- Do not add category to desktop file that is already there.
* Tue May  5 2009 opensuse@sukimashita.com
- Update to version 1.60:
  + All Platforms
  - Seed ratio limiting
  - Transfer prioritization
  - Option to specify if transfers are included in the global
    bandwidth limits
  - Random port, with optional randomization on startup
  - Improvements to UPnP port forwarding
  - Support for file preallocation on XFS filesystems
  + Mac
  - Requires Mac OS X 10.5 Leopard or newer
  - Groups (moved to preferences) can be auto-assigned to
    transfers when adding based on multiple criteria
  - Groups can have a default location when adding transfers
  - The speed limit scheduler can now be applied to only
    specific days
  - Bonjour support for the web interface
  - File filter field in the inspector
  - Option to include beta releases when auto-updating
    (using modified Sparkle 1.5)
  - Portuguese localization
  + Qt
  - New beta Qt client!
  + GTK+
  - Speed Limit: Second set of bandwidth limits that can be
    toggled or scheduled
  - Properties dialog now lets you edit/view multiple torrents
    at once
  - Allow sorting of the torrent list by size and by ETA
  - Show the file icon in the list
  + Daemon
  - Watch folder for auto-adding torrents
  - Many new features in the RPC/JSON interface
  - Allow users to specify a specific address when listening for
    peers
  + Web Client
  - File selection and prioritization
  - Add option to verify local data
  - Fix "Remove Data" bug
* Mon Apr 13 2009 mboman@suse.de
- Update to version 1.52:
  + GTK+ and Daemon
  * Always honor the XDG setting for the download directory
  + GTK+
  * Fix formatting error when showing speeds measured in MB/s
  * Fix bug that caused some scheduled speed limit time settings
    to be lost
  * Use the new blocklist URL when updating the blocklist
  + Web Client
  * On the server, better filtering of bad URLs
  * On the server, faster json serialization
  * Fix "Remove Data" bug
  * Fix minor web client 301 redirect error
  * Better Internet Explorer support
* Fri Feb 27 2009 vuntz@novell.com
- Update to version 1.51:
  + All Platforms
  - Fix configure script issues with non-gcc compilers and
    user-defined CFLAGS environment variables
  - Decrease CPU usage in some situations
  - Close a rare race condition on startup
  - More efficient use of libcurl when curl 7.18.0 or newer is
    present
  + GTK+
  - Play nicely with Ubuntu's new notification server
  - Add Pause All and Resume All buttons
  + Web Client
  - Support for Internet Explorer
  - Layout fixes when viewed on an iPhone/iPod touch
* Sat Feb 14 2009 mboman@suse.de
- Update to version 1.50:
  + All Platforms
  * IPv6 support for peers, and for trackers with explicit IPv6
    addresses
  * Improved connectivity for encrypted peers
  * Fix 1.42 error that made tracker announces slower over time
  * Fix a Mac-centric peer connection bug from 1.41
  * Use less CPU cycles when managing very fast peers
  * Better handling of non-UTF-8 torrent files
  * When removing local data, only remove data from the torrent
  * Close potential DoS vulnerability in 1.41
  * Many other bugfixes
  + GTK+
  * Various usability improvements
  * Better Gnome HIG compliance in the statusbar, properties
    dialog, and more
  + Daemon
  * Lots of new options added to transmission-remote
  * Fix 1.42 whitelist bug
  * Make i18n support optional for cli and daemon clients
  + CLI
  * Support session.json settings, just as the Daemon and GTK+
    clients do
  + Web Interface
  * Torrents can now be added by URL
  * Add the ability to "remove local data" from the web client
- Include web pages in the main package
* Tue Feb 10 2009 vuntz@novell.com
- Review changes.
* Sun Dec 28 2008 lmedinas@gmail.com
- Update to version 1.42:
  + Lot's of changes and bugfixes; see included NEWS file.
* Sat Dec 20 2008 mboman@suse.de
- Update to version 1.40:
  + All Platforms
  - Tracker communication uses fewer resources
  - More accurate bandwidth limits
  - Reduce disk fragmentation by preallocating files
  - Stability, security, and performance improvements to the RPC/Web UI
    server
  - Support compression when serving Web UI and RPC responses
  - Simplify the RPC whitelist
  - Fix bug that prevented handshakes with encrypted BitComet peers
  - Fix 1.3x bug that could re-download some data unnecessarily
  - Lazy bitfields
  + Mac
  - Option to automatically update the blocklist weekly
  - In the file inspector tab, show progress and size for folders
  - Scrollbars correctly appear when the main window auto-resizes
  - Sparkle updated to 1.5b6
  + GTK+
  - Option to automatically update the blocklist weekly
  - Added off-hour bandwidth scheduling
  - Simplify file/priority selection in the details dialog
  - Fix a couple of crashes
  + Web Client
  - The Web Client is now out of beta
  - Minor display fixes
  - On iPhone/iPod touch, launching from the home screen hides the address
    bar
  + Daemon
  - Added the ability to get detailed peer information on torrents
  - Fix bug that didn't handle --config-dir and TRANSMISSION_HOME correctly
  - Windows portability
  + Translation updates
* Tue Sep 23 2008 maw@suse.de
- Update to version 1.34:
  + All Clients:
  * Don't reconnect too frequently to the same peer
  * Webseed bugfix
  * Fix bug that caused some transfers to not be scraped
  * Handle OpenTracker's `downloaded' key in announce responses
  + GTK+
  * Minor display fixes
  * Updated translations
  + Daemon+:
  * Minor display fixes
  + Web Client:
  * Minor display fixes
  + CLI:
  * Fix crash when creating a torrent file.
* Fri Sep 12 2008 maw@suse.de
- Update to version 1.33:
  + Too many changes and bugfixes to list; see the included NEWS
    file.
* Fri Aug 22 2008 meissner@suse.de
- actually use optflags.
* Mon Apr 14 2008 vuntz@suse.de
- Update to version 1.11:
  + Fix a couple of minor display issues
* Fri Apr  4 2008 vuntz@suse.de
- Import from the build service, with cleanups.
* Thu Apr  3 2008 awafaa@opensuse.org
- Initial build in new repository
- Create a .changes file
* Sat Mar 29 2008 Pascal Bleser <guru@unixtech.be> 1.10
- new upstream version
* Wed Feb 27 2008 Pascal Bleser <guru@unixtech.be> 1.06
- new upstream version
* Sat Feb  9 2008 Pascal Bleser <guru@unixtech.be> 1.05
- new upstream version
* Sat Feb  2 2008 Pascal Bleser <guru@unixtech.be> 1.04
- new upstream version
* Wed Jan 30 2008 Pascal Bleser <guru@unixtech.be> 1.03
- new upstream version
* Wed Jan 23 2008 Pascal Bleser <guru@unixtech.be> 1.02
- new upstream version
* Sat Jan 12 2008 Pascal Bleser <guru@unixtech.be> 1.01
- update to 1.01
* Sat Jan  5 2008 Pascal Bleser <guru@unixtech.be> 1.00
- update to 1.00
* Wed Jan  2 2008 Pascal Bleser <guru@unixtech.be> 0.96
- update to 0.96
* Wed Dec  5 2007 Pascal Bleser <guru@unixtech.be> 0.95
- update to 0.95
* Tue Nov 27 2007 Pascal Bleser <guru@unixtech.be> 0.94
- update to 0.94
* Tue Nov 13 2007 Pascal Bleser <guru@unixtech.be> 0.93
- update to 0.93
* Mon Oct 29 2007 Pascal Bleser <guru@unixtech.be> 0.91
- removed libevent BuildRequires, has an in-tree copy that is used anyway
- update to 0.91
* Thu Oct 25 2007 Pascal Bleser <guru@unixtech.be> 0.90
- lots of upstream cleanups, dropped patches
- gettext translations are now in the main package instead of in -gtk
- several binary renames
- man pages have been removed by upstream
- uses autotools now
- zsh completion has been removed by upstream
- update to 0.90
* Wed Oct  3 2007 Pascal Bleser <guru@unixtech.be> 0.82
- cli subpackage merged in (and provided by main package)
- gtk subpackage split out
- merged with Carlos Rodgriguez' transmission spec file
- moved to openSUSE Build Service
* Sun Sep 23 2007 Pascal Bleser <guru@unixtech.be> 0.82-0.pm.1
- moved to Packman
- new upstream version
* Tue Aug  7 2007 Pascal Bleser <guru@unixtech.be> 0.80-1
- new upstream version
* Tue May  1 2007 Pascal Bleser <guru@unixtech.be> 0.72-1
- now builds transmission daemon, proxy and remote
- new upstream version
* Tue Apr 24 2007 Pascal Bleser <guru@unixtech.be> 0.71-1
- new upstream version
* Wed Apr 18 2007 Pascal Bleser <guru@unixtech.be> 0.70-1
- new upstream version
* Fri Nov 10 2006 Pascal Bleser <guru@unixtech.be> 0.6.1-2
- added patch to disable broken gtk2 version test in configure, to build properly on 10.2beta with GTK2 2.10.x and enforce >= 2.6.0 through BuildRequires instead
* Tue Aug  8 2006 Pascal Bleser <guru@unixtech.be> 0.6.1-1
- new package
